==> seedsui-react-2.6.2.tgz: package/es/Stencil/Stencil.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { createPortal } from 'react-dom';

var Stencil = (_temp = _class = function (_Component) {
  _inherits(Stencil, _Component);

  function Stencil(props) {
    _classCallCheck(this, Stencil);

    return _possibleConstructorReturn(this, _Component.call(this, props));
  }

  Stencil.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        className = _props.className,
        others = _objectWithoutProperties(_props, ['className']);

    return createPortal(React.createElement('div', _extends({ ref: function ref(el) {
        _this2.$el = el;
      }, className: 'stencil' + (className ? ' ' + className : '') }, others)), this.props.portal || document.getElementById('root'));
  };

  return Stencil;
}(Component), _class.defaultProps = {
  className: 'stencil-list'
}, _temp);
export { Stencil as default };
Stencil.propTypes = process.env.NODE_ENV !== "production" ? {
  className: PropTypes.string,
  style: PropTypes.object
} : {};

==> seedsui-react-2.7.4.tgz: package/es/Stencil/Stencil.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { createPortal } from 'react-dom';

var Stencil = (_temp = _class = function (_Component) {
  _inherits(Stencil, _Component);

  function Stencil(props) {
    _classCallCheck(this, Stencil);

    return _possibleConstructorReturn(this, _Component.call(this, props));
  }

  Stencil.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        className = _props.className,
        others = _objectWithoutProperties(_props, ['className']);

    return createPortal(React.createElement('div', _extends({ ref: function ref(el) {
        _this2.$el = el;
      }, className: 'stencil' + (className ? ' ' + className : '') }, others)), this.props.portal || document.getElementById('root') || document.body);
  };

  return Stencil;
}(Component), _class.defaultProps = {
  className: 'stencil-list'
}, _temp);
export { Stencil as default };
Stencil.propTypes = process.env.NODE_ENV !== "production" ? {
  className: PropTypes.string,
  style: PropTypes.object
} : {};
